@@ -12,14 +12,13 @@ from .print_versions import show_versions
 from .pydaymet import get_bycoords, get_bygeom
 
 try:
-    import importlib.metadata as metadata
+    import importlib.metadata
 except ImportError:
-    import importlib_metadata as metadata  # type: ignore[no-redef]
+    import importlib_metadata
 
-try:
-    __version__ = metadata.version("pydaymet")
-except Exception:
-    __version__ = "999"
+    __version__ = importlib_metadata.version("pydaymet")
+else:
+    __version__ = importlib.metadata.version("pydaymet")
 
 __all__ = [
     "Daymet",
